@@ -144,12 +144,13 @@ def update_or_create_redis_instance_from_django_instance(
             **redis_dict
         ).save()
     else:
+        redis_instance = redis_instance[0]
         redis_root.update(redis_model, redis_instance,
                           django_id=django_instance.id,
                           **redis_dict
                           )
 
-    result_redis_instance = redis_root.get(redis_model, django_id=django_instance.id)
+    result_redis_instance = redis_root.get(redis_model, django_id=django_instance.id)[0]
     return result_redis_instance
 
 
@@ -218,5 +219,8 @@ def get_or_create_redis_instance_from_django_instance(
             django_id=django_instance.id,
             **redis_dict
         ).save()
-        redis_instance = redis_root.get(redis_model, django_id=django_instance.id)
+        redis_instance = redis_root.get(redis_model, django_id=django_instance.id)[0]
+    else:
+        redis_instance = redis_instance[0]
+    print(type(redis_instance))
     return redis_instance
