@@ -150,8 +150,7 @@ class RedisForeignKey(RedisNumber):
     def clean(self):
         self.value = self.check_value()
         if self.value not in [None, 'null']:
-            print(self.value)
-            self.value = get_ids_from_untyped_data(self.value)
+            self.value = get_ids_from_untyped_data(self.value)[0]
         return super().clean()
 
     def _get_instance_by_id(self, id, redis_root):
